==> cmood-8.x-1.0.tar.gz: cmood/src/Controller/CmoodController.php <==
<?php

namespace Drupal\cmood\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\cmood\Storage\CmoodStorage;
use Drupal\Component\Utility\SafeMarkup;
use Drupal\Component\Utility\Unicode;
use Drupal\Core\Url;

/**
 * Class CmoodController implements controller class for cmood menu items and consist helper functions.
 */
class CmoodController extends ControllerBase {

  /**
   * List content with there moods as a table list
   * 
   * @return string
   */
  public static function cmoodNodeMoodListing() {
    $header = array(
      array('data' => t('ID'), 'field' => 'id', 'sort' => 'asc'),
      array('data' => t('Node Title'), 'field' => 'title'),
      array('data' => t('Node Mood'), 'field' => 'mood'),
    );
    $rows = array();
    foreach (CmoodStorage::getCmoodContent($header) as $row) {
      $rows[] = array($row->id,
        Unicode::truncate(SafeMarkup::checkPlain($row->title), 30),
        $row->mood,
      );
    }
    $table = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    );
    return array(
      '#type' => 'markup',
      '#markup' => drupal_render($table),
    );
  }

  /**
   * List rank associated with each cmood word
   * 
   * @return string
   */
  public static function cmoodRankWordListing() {
    $header = array(
      array('data' => t('RWID'), 'field' => 'rwid', 'sort' => 'asc'),
      array('data' => t('Word'), 'field' => 'name'),
      array('data' => t('Weight'), 'field' => 'weight'),
      array('data' => t('UID'), 'field' => 'uid'),
      array('data' => t('Edit'), 'field' => 'edit'),
      array('data' => t('Delete'), 'field' => 'delete'),
    );
    $rows = array();
    foreach (CmoodStorage::getCmoodWordsRank($header) as $row) {
      $url = Url::fromRoute('cmood.edit_rank_word', array('rwid' => $row->rwid));
      $url_delete = Url::fromRoute('cmood.rank_word_delete', array('rwid' => $row->rwid));
      $rows[] = array($row->rwid,
        SafeMarkup::checkPlain($row->name),
        $row->weight,
        $row->uid,
        \Drupal::l(t('Edit'), $url),
        \Drupal::l(t('Delete'), $url_delete),
      );
    }
    $table = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    );
    return array(
      '#type' => 'markup',
      '#markup' => drupal_render($table),
    );
  }

  /**
   * List all added mood words
   * 
   * @return string
   */
  public static function cmoodMoodWordListing() {
    $header = array(
      array('data' => t('WID'), 'field' => 'wid', 'sort' => 'asc'),
      array('data' => t('Word'), 'field' => 'name'),
      array('data' => t('Weight'), 'field' => 'weight'),
      array('data' => t('UID'), 'field' => 'uid'),
      array('data' => t('Edit'), 'field' => 'Edit'),
      array('data' => t('Delete'), 'field' => 'Delete'),
    );
    $rows = array();
    foreach (CmoodStorage::getCmoodWords($header) as $row) {
      $url = Url::fromRoute('cmood.edit_mood_word', array('wid' => $row->wid));
      $url_delete = Url::fromRoute('cmood.mood_word_delete', array('wid' => $row->wid));
      $rows[] = array($row->wid,
        SafeMarkup::checkPlain($row->name),
        $row->weight,
        $row->uid,
        \Drupal::l(t('Edit'), $url),
        \Drupal::l(t('Delete'), $url_delete),
      );
    }
    $table = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    );
    return array(
      '#type' => 'markup',
      '#markup' => drupal_render($table),
    );
  }

  /**
   * Gets edit form for Edit mood word
   * 
   * @param int $wid
   *   mood word id.
   */
  public function cmoodEditMoodWord($wid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\CmoodAddMoodWord', $wid);
    return $form;
  }

  /**
   * Gets edit form for Edit rank word
   * 
   * @param int $rwid
   *   rank word id.
   */
  public function cmoodEditRankWord($rwid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\CmoodAddRankWord', $rwid);
    return $form;
  }

  /**
   * Gets delete form for mood word
   * 
   * @param int $wid
   *   mood word id.
   */
  public function cmoodDeleteMoodWord($wid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\DeleteMoodWordConfirm', $wid);
    return $form;
  }

  /**
   * Gets delete form for rank word
   * 
   * @param int $rwid
   *   rank word id.
   */
  public function cmoodDeleteRankWord($rwid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\DeleteMoodRankConfirm', $rwid);
    return $form;
  }

}

==> cmood-8.x-1.1.tar.gz: cmood/src/Controller/CmoodController.php <==
<?php

namespace Drupal\cmood\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\cmood\Storage\CmoodStorage;
use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\Unicode;
use Drupal\Core\Url;

/**
 * Class CmoodController implements controller class for cmood menu items and consist helper functions.
 */
class CmoodController extends ControllerBase {

  /**
   * List content with there moods as a table list
   * 
   * @return string
   */
  public static function cmoodNodeMoodListing() {
    $header = array(
      array('data' => t('ID'), 'field' => 'id', 'sort' => 'asc'),
      array('data' => t('Node Title'), 'field' => 'title'),
      array('data' => t('Node Mood'), 'field' => 'mood'),
    );
    $rows = array();
    foreach (CmoodStorage::getCmoodContent($header) as $row) {
      $rows[] = array($row->id,
        Unicode::truncate(Html::escape($row->title), 30),
        $row->mood,
      );
    }
    $table = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    );
    return array(
      '#type' => 'markup',
      '#markup' => \Drupal::service('renderer')->render($table),
    );
  }

  /**
   * List rank associated with each cmood word
   * 
   * @return string
   */
  public static function cmoodRankWordListing() {
    $header = array(
      array('data' => t('RWID'), 'field' => 'rwid', 'sort' => 'asc'),
      array('data' => t('Word'), 'field' => 'name'),
      array('data' => t('Weight'), 'field' => 'weight'),
      array('data' => t('UID'), 'field' => 'uid'),
      array('data' => t('Edit'), 'field' => 'edit'),
      array('data' => t('Delete'), 'field' => 'delete'),
    );
    $rows = array();
    foreach (CmoodStorage::getCmoodWordsRank($header) as $row) {
      $url = Url::fromRoute('cmood.edit_rank_word', array('rwid' => $row->rwid));
      $url_delete = Url::fromRoute('cmood.rank_word_delete', array('rwid' => $row->rwid));
      $rows[] = array($row->rwid,
        Html::escape($row->name),
        $row->weight,
        $row->uid,
        \Drupal::l(t('Edit'), $url),
        \Drupal::l(t('Delete'), $url_delete),
      );
    }
    $table = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    );
    return array(
      '#type' => 'markup',
      '#markup' => \Drupal::service('renderer')->render($table),
    );
  }

  /**
   * List all added mood words
   * 
   * @return string
   */
  public static function cmoodMoodWordListing() {
    $header = array(
      array('data' => t('WID'), 'field' => 'wid', 'sort' => 'asc'),
      array('data' => t('Word'), 'field' => 'name'),
      array('data' => t('Weight'), 'field' => 'weight'),
      array('data' => t('UID'), 'field' => 'uid'),
      array('data' => t('Edit'), 'field' => 'Edit'),
      array('data' => t('Delete'), 'field' => 'Delete'),
    );
    $rows = array();
    foreach (CmoodStorage::getCmoodWords($header) as $row) {
      $url = Url::fromRoute('cmood.edit_mood_word', array('wid' => $row->wid));
      $url_delete = Url::fromRoute('cmood.mood_word_delete', array('wid' => $row->wid));
      $rows[] = array($row->wid,
        Html::escape($row->name),
        $row->weight,
        $row->uid,
        \Drupal::l(t('Edit'), $url),
        \Drupal::l(t('Delete'), $url_delete),
      );
    }
    $table = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    );
    return array(
      '#type' => 'markup',
      '#markup' => \Drupal::service('renderer')->render($table),
    );
  }

  /**
   * Gets edit form for Edit mood word
   * 
   * @param int $wid
   *   mood word id.
   */
  public function cmoodEditMoodWord($wid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\CmoodAddMoodWord', $wid);
    return $form;
  }

  /**
   * Gets edit form for Edit rank word
   * 
   * @param int $rwid
   *   rank word id.
   */
  public function cmoodEditRankWord($rwid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\CmoodAddRankWord', $rwid);
    return $form;
  }

  /**
   * Gets delete form for mood word
   * 
   * @param int $wid
   *   mood word id.
   */
  public function cmoodDeleteMoodWord($wid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\DeleteMoodWordConfirm', $wid);
    return $form;
  }

  /**
   * Gets delete form for rank word
   * 
   * @param int $rwid
   *   rank word id.
   */
  public function cmoodDeleteRankWord($rwid) {
    $form = \Drupal::formBuilder()->getForm('Drupal\cmood\Form\DeleteMoodRankConfirm', $rwid);
    return $form;
  }

}
